[][src]Struct generic_tree::Tree

pub struct Tree<K, V> { /* fields omitted */ }

A Tree represents and owns a collection of Nodes. It should be the go-to point for interacting with elements wihtin the structure.

Implementations

impl<K, V> Tree<K, V> where
    K: PartialEq
[src]

pub fn init(root: Node<K, V>) -> Self[src]

Create a new tree, given the root Node root.

pub fn get_node<Q>(&self, path: &[Q]) -> Result<&Node<K, V>, Error> where
    Q: PartialEq<K>, 
[src]

Get a reference to a specific Node from the tree, resolved by the list provided by path.

Errors

Returns an Err if path doesn't resolve to a Node.

Examples

let mut root = Node::new("root", 1);
let child = Node::new("child", 2);
root.add_child(child);

let mut tree = Tree::init(root);

assert!(tree.get_node(&["root"]).is_ok());
assert!(tree.get_node(&["root", "child"]).is_ok());
assert!(tree.get_node(&["boot"]).is_err());
assert!(tree.get_node(&["root", "child", "noop"]).is_err());

pub fn get_mut_node<Q>(&mut self, path: &[Q]) -> Option<&mut Node<K, V>> where
    Q: PartialEq<K>, 
[src]

Get a mutable reference to a specific Node from the tree, resolved by the list provided by path.

Errors

Returns an Err if path doesn't resolve to a Node.

Examples

use generic_tree::{Tree, Node};

let mut root = Node::new("root", 1);
let child = Node::new("child", 2);
root.add_child(child);

let mut tree = Tree::init(root);

let mut node = tree.get_mut_node(&["root", "child"]).unwrap();
assert_eq!(node.value(), &2);

*node.mut_value() = 42;

pub fn add_node<Q>(
    &mut self,
    path: &[Q],
    node: Node<K, V>
) -> Result<Option<Box<Node<K, V>>>, Error> where
    Q: PartialEq<K>, 
[src]

Add a Node as a child to the Node resolved by path. If there was already a Node with the same key, that old Node is returned.

Errors

Returns an Err if path doesn't resolve to a Node.

Examples

let mut root = Node::new("root", 1);
let mut tree = Tree::init(root);

let child = Node::new("child", 2);
tree.add_node(&["root"], child);

pub fn remove_node<Q>(&mut self, path: &[Q]) -> Result<Box<Node<K, V>>, Error> where
    Q: PartialEq<K>, 
[src]

Remove a Node from the tree resolved by path.

Errors

Returns an Err if path doesn't resolve to a Node.

Examples

let mut root = Node::new("root", 1);
let child = Node::new("child", 2);
root.add_child(child);
let mut tree = Tree::init(root);

assert!(tree.remove_node(&["root", "child"]).is_ok());